import mbuild as mb

from CH2_UA import CH2_UA
from CH3_UA import CH3_UA

class C5P(mb.Compound):
    """ A united-atom alkane chain, optionally terminated by CH3 particles"""
    def __init__(self, n=6, cap_front=True, cap_end=True):
        """Initialize an UA_alkane Compound.

        Args:
            n: Number of backbone particles.
            cap_front: Add methyl group to beginning of chain ('down' port).
            cap_end: Add methyl group to end of chain ('up' port).
        """
        if n < 2:
            raise Exception('n must be 1 or more')
        super(C5P, self).__init__()

        # Adjust length of Polmyer for absence of methyl terminations.
        if not cap_front:
            n += 1
        if not cap_end:
            n += 1
        chain = mb.Polymer(CH2_UA(), n=n-2, port_labels=('up', 'down'))
        self.add(chain, 'chain')

        if cap_front:
            self.add(CH3_UA(), "methyl_front")
            mb.equivalence_transform(self['chain'], self['chain']['up'], self['methyl_front']['up'])
        else:
            # Hoist port label to UA_alkane level.
            self.add(chain['up'], 'up', containment=False)

        if cap_end:
            self.add(CH3_UA(), 'methyl_end')
            mb.equivalence_transform(self['methyl_end'], self['methyl_end']['up'], self['chain']['down'])
        else:
            # Hoist port label to UA_alkane level.
            self.add(chain['down'], 'down', containment=False)

if __name__ == "__main__":
    from foyer import Forcefield
    n = 5
    untyped_chain = C5P(n=n, cap_front=True, cap_end=True)
    structure = untyped_chain.to_parmed()
    forcefield = Forcefield('./Mie_forcefield.xml')
    import pdb; pdb.set_trace()
    chain = forcefield.apply(structure)
    chain.save('ua_C{}H.pdb'.format(n), overwrite=True)
    chain.save('ua_C{}H.psf'.format(n), overwrite=True)
